Crate monedero_jup_ag

Crate monedero_jup_ag 

Structs

DynamicSlippage
FeeInfo
JupiterInstructor
PlatformFee
Price
PriceResponse
Quote
QuoteConfig
RoutePlan
Swap
Partially signed transactions required to execute a swap
SwapInfo
SwapInstructions
Swap instructions
SwapRequest

Enums

Error
PrioritizationFeeLamports
PriorityLevel
Represents the priority levels for the PriorityLevelWithMaxLamports variant.
SwapMode

Functions

price
Get simple price for a given input mint, output mint, and amount
program_id_to_label
Get a hashmap, which key is the program id and value is the label. This is used to help map error from transaction by identifying the fault program id. With that, we can use the excludeDexes or dexes parameter.
quote
Get quote for a given input mint, output mint, and amount
swap
Get swap serialized transactions for a quote
swap_instructions
Get swap serialized transaction instructions for a quote
tokens
Returns a list of all the tradable mints

Type Aliases

DexProgramIdToLabel
Hashmap, which key is the program id and value is the label. This is used to help map error from transaction by identifying the fault program id. With that, we can use the excludeDexes or dexes parameter.
Result