Structs
- Dynamic
Slippage - FeeInfo
- Jupiter
Instructor - Platform
Fee - Price
- Price
Response - Quote
- Quote
Config - Route
Plan - Swap
- Partially signed transactions required to execute a swap
- Swap
Info - Swap
Instructions - Swap instructions
- Swap
Request
Enums
- Error
- Prioritization
FeeLamports - Priority
Level - Represents the priority levels for the
PriorityLevelWithMaxLamportsvariant. - Swap
Mode
Functions
- price
- Get simple price for a given input mint, output mint, and amount
- program_
id_ to_ label - Get a hashmap, which key is the program id and value is the label. This is used to help map error from transaction by identifying the fault program id. With that, we can use the excludeDexes or dexes parameter.
- quote
- Get quote for a given input mint, output mint, and amount
- swap
- Get swap serialized transactions for a quote
- swap_
instructions - Get swap serialized transaction instructions for a quote
- tokens
- Returns a list of all the tradable mints
Type Aliases
- DexProgram
IdTo Label - Hashmap, which key is the program id and value is the label. This is used to help map error from transaction by identifying the fault program id. With that, we can use the excludeDexes or dexes parameter.
- Result